@@ -306,18 +306,17 @@ class Model(dict):
         return data
 
 
-    def _create_class(cls):
-        class JSONObject(cls):
+    def _create_class(self):
+        class JSONObject(self.__class__):
             def __init__(self, d):
                 self.__dict__ = d
         return JSONObject
 
     def to_json(self):
-        obj=self.execute()
-        return json.dumps(obj, default=lambda obj: obj.__dict__)
+        return json.dumps(self.execute(), default=lambda obj: obj.__dict__)
 
-    def to_object(data, obj):
-        return json.loads(data, object_hook=createClass(obj.__module__))
+    def to_object(self):
+        return json.loads(self.to_json(), object_hook=self._create_class())
 
 
 @staticmethod
@@ -333,5 +332,6 @@ def toJson(obj):
 
 
 @staticmethod
-def toObject(data, obj):
-    return json.loads(data,object_hook=createClass(obj.__module__))
\ No newline at end of file
+def toObject(data, cls):
+    return json.loads(data,object_hook=createClass(cls))
+
